*株式会社ライトストーン
*Stata分析機能例題集　ベイズ推定

*データセットをダウンロードして内容を確認
use https://www.stata-press.com/data/r16/oxygen, clear
describe


***************例題1: OLS***************

*OLSモデルにフィット
regress change group age


*****例題2: 事前情報のないベイズ正規線形回帰*****

*ベイズ線形回帰でフィット
bayesmh change group age, likelihood(normal({var})) prior({change:}, flat) prior({var}, jeffreys)

*乱数シードを設定して分析結果を再現可能にする
set seed 14
bayesmh change group age, likelihood(normal({var})) prior({change:}, flat) prior({var}, jeffreys)


*****例題3: 事前情報のあるベイズ線形回帰*****

*フィット実行
set seed 14
bayesmh change group age, likelihood(normal({var})) prior({change:}, normal(0, {var})) prior({var}, igamma(2.5, 2.5))


*****例題4: 多変量事前情報のベイズ正規線形回帰*****

*フィット実行
set seed 14
bayesmh change group age, likelihood(normal({var})) prior({change:}, zellnersg0(3,12,{var})) prior({var}, igamma(0.5, 4))


***************例題5: 収束の確認***************

*診断グラフ作成
bayesgraph diagnostics {change:group}

*有効なサンプルサイズと収束に関する統計量を表示
bayesstats ess

*分散パラメータを独立したブロックに分割してフィット
set seed 14
bayesmh change group age, likelihood(normal({var})) prior({change:}, zellnersg0(3,12,{var})) prior({var}, igamma(0.5, 4)) block({var}) saving(agegroup_simdata)

*推定結果を保存
estimates store agegroup


***************例題6: 推定後要約***************

*推定後の要約
summarize group
scalar sd_x = r(sd)
summarize change
scalar sd_y = r(sd)
bayesstats summary (group_std:{change:group}*sd_x/sd_y)


***************例題7: ベイズ予測***************

*新しいデータセットを保存
bayespredict {_ysim}, saving(change_pred) rseed(16)

*予測された観測値の事後要約を計算
bayesstats summary {_ysim} using change_pred

*複製標本と観測標本を比較
bayesstats ppvalues {_ysim} using change_pred

*新しく2つの観測値を追加し標本外予測を行う
set obs 14
replace group = 1 in 13
replace group = 0 in 14
replace age = 26 in 13/14
bayespredict pmean, mean rseed(16)
list change age group pmean


***************例題8: モデルの比較***************

*ここまで推定モデルと誤差項を含む 完全モデルを比較
set seed 14
bayesmh change group age ageXgr, likelihood(normal({var})) prior({change:}, zellnersg0(4,12,{var})) prior({var}, igamma(0.5, 4)) block({var}) saving(full_simdata)
estimates store full
bayesstats ic full agegroup


***************例題9: 仮説検定***************

*モデルの実際の確率を計算
bayestest model full agegroup

*パラメータ区間の仮設検定
estimates restore agegroup
bayestest interval {change:group}, lower(4) upper(8)


*****例題10: シミュレーションデータセットの削除*****

*シミュレーション用のデータセットを削除
erase agegroup_simdata.dta
erase full_simdata.dta

